.. Copyright 2011, 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Domain functionality
====================

.. toctree::
   :maxdepth: 2

   User accounts for logging in (reahl.systemaccountmodel) <systemaccountmodel>
   Simple workflow queues and tasks (reahl.workflowmodel) <workflowmodel>
   
   A user interface for logging in and registering  (reahl.domainui.accounts) <systemaccountui>
   A user interface for monitoring workflow queues and tasks (reahl.domainui.workflow) <workflowui>

   Tools for handling simple email (reahl.mailutil.mail) <mail>
   Restructured text (reahl.mailutil.rst) <rst>